StorageError

Enum StorageError 

pub enum StorageError {
    AllocError(Layout),
    CapacityLimit,
    LayoutError(LayoutError),
    ProtectionError,
    Unsupported,
}
An enumeration of error types raised by storage implementations.

Variants



AllocError(Layout)

A memory allocation failed.



CapacityLimit

The limit of the current allocation was reached.



LayoutError(LayoutError)

The provided layout was not allocatable.



ProtectionError

Memory protection failed.



Unsupported

The requested operation is not supported for this storage.

Implementations

Source

impl StorageError

pub fn as_str(&self) -> &'static str

Generic description of this error.

pub fn panic(self) -> !

Generate a panic with this error as the reason.