pub trait Grow: Debug {
// Required method
fn next_capacity<T, I: Index>(prev: I, minimum: I) -> I;
}Expand description
Growth behavior for collections which have exceeded their available storage
Required Methods
Sourcefn next_capacity<T, I: Index>(prev: I, minimum: I) -> I
fn next_capacity<T, I: Index>(prev: I, minimum: I) -> I
Calculate the next capacity to request from the allocator
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".